@@ -1,6 +1,6 @@
 use std::num::ParseIntError;
 
-fn main() -> Result<(), ParseIntError> {
+pub fn main() -> Result<(), ParseIntError> {
     let _a = i32::from_str_radix("a12", 10)?;
     Ok(())
 }
